@@ -7,27 +7,47 @@ from valo_api.utils.fetch_endpoint import fetch_endpoint
 
 
 def get_match_history_by_name_v3(
-    region: str, name: str, tag: str, size: Optional[int] = None, **kwargs
+    region: str,
+    name: str,
+    tag: str,
+    size: Optional[int] = None,
+    game_mode: Optional[str] = None,
+    **kwargs,
 ) -> Union[List[MatchHistoryPointV3], ErrorResponse]:
-    return get_match_history_by_name("v3", region, name, tag, size, **kwargs)
+    return get_match_history_by_name("v3", region, name, tag, size, game_mode, **kwargs)
 
 
 def get_match_history_by_puuid_v3(
-    region: str, puuid: str, size: Optional[int] = None, **kwargs
+    region: str,
+    puuid: str,
+    size: Optional[int] = None,
+    game_mode: Optional[str] = None,
+    **kwargs,
 ) -> Union[List[MatchHistoryPointV3], ErrorResponse]:
-    return get_match_history_by_puuid("v3", region, puuid, size, **kwargs)
+    return get_match_history_by_puuid("v3", region, puuid, size, game_mode, **kwargs)
 
 
 def get_match_history_by_name(
-    version: str, region: str, name: str, tag: str, size: Optional[int] = None, **kwargs
+    version: str,
+    region: str,
+    name: str,
+    tag: str,
+    size: Optional[int] = None,
+    game_mode: Optional[str] = None,
+    **kwargs,
 ) -> Union[List[MatchHistoryPointV3], ErrorResponse]:
+    query_args = dict()
+    if size:
+        query_args["size"] = str(size).lower()
+    if game_mode:
+        query_args["filter"] = game_mode.lower()
     response = fetch_endpoint(
         EndpointsConfig.MATCH_HISTORY_BY_NAME,
         version=version,
         region=region,
         name=name,
         tag=tag,
-        query_args={"size": str(size).lower()} if size else None,
+        query_args=query_args,
         **kwargs,
     )
     response_data = response.json()
@@ -39,14 +59,24 @@ def get_match_history_by_name(
 
 
 def get_match_history_by_puuid(
-    version: str, region: str, puuid: str, size: Optional[int] = None, **kwargs
+    version: str,
+    region: str,
+    puuid: str,
+    size: Optional[int] = None,
+    game_mode: Optional[str] = None,
+    **kwargs,
 ) -> Union[List[MatchHistoryPointV3], ErrorResponse]:
+    query_args = dict()
+    if size:
+        query_args["size"] = str(size).lower()
+    if game_mode:
+        query_args["filter"] = game_mode.lower()
     response = fetch_endpoint(
         EndpointsConfig.MATCH_HISTORY_BY_PUUID,
         version=version,
         region=region,
         puuid=puuid,
-        query_args={"size": str(size).lower()} if size else None,
+        query_args=query_args,
         **kwargs,
     )
     response_data = response.json()
